require 'uu/os/rest/dto'
require 'uu/os/uesuri'

module UU
  module Finman
    module BusinessCase
      # Value object defining data required (available) for creating new Business Case entity.
      class BusinessCaseCreate < UU::OS::REST::DTO

        # URI of meta artifact of created Business Case. Required attribute.
        # When null is set or object referenced by the URI is not meta artifact of business case, create command will fail.
        # @param [String, UU::OS::UESURI]
        # @return [UU::OS::UESURI]
        attr_accessor :meta_artifact_uri

        # Name of created business case. Required attribute.
        # Its value is automatically trimmed. Cannot be null nor empty string nor longer than 250 characters.
        # The create command fails otherwise.
        # @param [String]
        # @return [String]
        attr_accessor :name

        # Code of created business case. Its value is automatically trimmed.
        # The code must be unique in target territory. It cannot be empty string nor longer than 250 characters.
        # The create command will fail otherwise.
        # When null is set, the code is generated automatically.
        # @param [String]
        # @return [String]
        attr_accessor :code

        # Description of created Business Case.
        # @param [String]
        # @return [String]
        attr_accessor :description

        # URI of the role competent for created Business Case. When null is set, competent role will be taken from authorization.
        # @param [String, UU::OS::UESURI]
        # @return [UU::OS::UESURI]
        attr_accessor :competent_role_uri

        # Code of business case currency. Must be one from territory allowed reporting currencies.
        # @param [String]
        # @return [String]
        attr_accessor :currency

        # URI of company of created business case. Required attribute.
        # When null is set, the create command will fail.
        # @param [String, UU::OS::UESURI]
        # @return [UU::OS::UESURI]
        attr_accessor :business_case_company_uri

        # URI of related business case of interterritorial business case.
        # If you try to set related business case on non interterriorial business case, the command will fail.
        # @param [String, UU::OS::UESURI]
        # @return [UU::OS::UESURI]
        attr_accessor :related_business_case_uri

        # URI of counterparty business case of interterritorial business case.
        # If you try to set counterparty business case on non interterriorial business case, the command will fail.
        # @param [String, UU::OS::UESURI]
        # @return [UU::OS::UESURI]
        attr_accessor :counterparty_business_case_uri

        # URI of access role for payments of interterritorial business case.
        # If you try to set access role for payments on non interterriorial business case, the command will fail.
        # @param [String, UU::OS::UESURI]
        # @return [UU::OS::UESURI]
        attr_accessor :access_role_for_payments_uri

        # URI of default account of the business case.
        # @param [String, UU::OS::UESURI]
        # @return [UU::OS::UESURI]
        attr_accessor :default_account_uri

        # Default account number of the business case.
        # @param [String]
        # @return [String]
        attr_accessor :default_account_number

        # URI of incoming invoice clerk's role.
        # @param [String, UU::OS::UESURI]
        # @return [UU::OS::UESURI]
        attr_accessor :incoming_invoice_clerk_uri

        # URI of outgoing invoice clerk's role.
        # @param [String, UU::OS::UESURI]
        # @return [UU::OS::UESURI]
        attr_accessor :outgoing_invoice_clerk_uri

        # URI of default financial category of credit side of payment.
        # @param [String, UU::OS::UESURI]
        # @return [UU::OS::UESURI]
        attr_accessor :payment_default_credit_financial_category_uri

        # URI of default financial category of debit side of payment.
        # @param [String, UU::OS::UESURI]
        # @return [UU::OS::UESURI]
        attr_accessor :payment_default_debit_financial_category_uri

        # URI of default financial category of credit side of fast payment.
        # @param [String, UU::OS::UESURI]
        # @return [UU::OS::UESURI]
        attr_accessor :fast_payment_default_credit_financial_category_uri

        # URI of default financial category of debit side of fast payment.
        # @param [String, UU::OS::UESURI]
        # @return [UU::OS::UESURI]
        attr_accessor :fast_payment_default_debit_financial_category_uri
        
        # URI of default financial category of credit side of financial transfer.
        # @param [String, UU::OS::UESURI]
        # @return [UU::OS::UESURI]
        attr_accessor :transfer_default_credit_financial_category_uri

        # URI of default financial category of debit side of financial transfer.
        # @param [String, UU::OS::UESURI]
        # @return [UU::OS::UESURI]
        attr_accessor :transfer_default_debit_financial_category_uri

        # URI of default financial category of credit side of ex-post payment.
        # @param [String, UU::OS::UESURI]
        # @return [UU::OS::UESURI]
        attr_accessor :expost_payment_default_credit_financial_category_uri

        # URI of default financial category of debit side of ex-post payment.
        # @param [String, UU::OS::UESURI]
        # @return [UU::OS::UESURI]
        attr_accessor :expost_payment_default_debit_financial_category_uri

        # URI of default financial category of supplier's side of credit note.
        # @param [String, UU::OS::UESURI]
        # @return [UU::OS::UESURI]
        attr_accessor :credit_note_supplier_default_financial_category_uri

        # URI of default financial category of client's side of credit note.
        # @param [String, UU::OS::UESURI]
        # @return [UU::OS::UESURI]
        attr_accessor :credit_note_client_default_financial_category_uri

        # Type of the business case..
        # Can be null, if the type of the business case is specified by attribute metaArtifactUri.
        # @param [UU::Finman::BusinessCase::BusinessCaseType]
        # @return [UU::Finman::BusinessCase::BusinessCaseType]
        attr_accessor :business_case_type

        # Dry run. If true, all validations will be processed, but payment
        # will not be created.
        # @param [TrueClass, FalseClass]
        # @return [TrueClass, FalseClass]
        attr_accessor :dry_run

        def meta_artifact_uri
          attributes[:metaArtifactUri]
        end

        def meta_artifact_uri=(val)
          if val
            attributes[:metaArtifactUri] = UU::OS::UESURI.new(val)
          else
            attributes[:metaArtifactUri] = nil
          end
        end

        def name
          attributes[:name]
        end

        def name=(val)
          attributes[:name] = val
        end

        def code
          attributes[:code]
        end

        def code=(val)
          attributes[:code] = val
        end

        def description
          attributes[:description]
        end

        def description=(val)
          attributes[:description] = val
        end

        def competent_role_uri
          attributes[:competentRoleUri]
        end

        def competent_role_uri=(val)
          if val
            attributes[:competentRoleUri] = UU::OS::UESURI.new(val)
          else
            attributes[:competentRoleUri] = nil
          end
        end

        def business_case_company_uri
          attributes[:businessCaseCompanyUri]
        end

        def business_case_company_uri=(val)
          if val
            attributes[:businessCaseCompanyUri] = UU::OS::UESURI.new(val)
          else
            attributes[:businessCaseCompanyUri] = nil
          end
        end

        def related_business_case_uri
          attributes[:relatedBusinessCaseUri]
        end

        def related_business_case_uri=(val)
          attributes[:relatedBusinessCaseUri] = val
        end

        def currency
          attributes[:currency]
        end

        def currency=(val)
          attributes[:currency] = val
        end

        def counterparty_business_case_uri
          attributes[:counterpartyBusinessCaseUri]
        end

        def counterparty_business_case_uri=(val)
          attributes[:counterpartyBusinessCaseUri] = val
        end

        def access_role_for_payments_uri
          attributes[:accessRoleForPaymentsUri]
        end

        def access_role_for_payments_uri=(val)
          attributes[:accessRoleForPaymentsUri] = val
        end

        def default_account_uri
          attributes[:defaultAccountUri]
        end

        def default_account_uri=(val)
          attributes[:defaultAccountUri] = val
        end

        def default_account_number
          attributes[:defaultAccountNumber]
        end

        def default_account_number=(val)
          attributes[:defaultAccountNumber] = val
        end

        def incoming_invoice_clerk_uri
          attributes[:incomingInvoiceClerkUri]
        end

        def incoming_invoice_clerk_uri=(val)
          attributes[:incomingInvoiceClerkUri] = val
        end

        def outgoing_invoice_clerk_uri
          attributes[:outgoingInvoiceClerkUri]
        end

        def outgoing_invoice_clerk_uri=(val)
          attributes[:outgoingInvoiceClerkUri] = val
        end


        def payment_default_credit_financial_category_uri
          attributes[:paymentDefaultCreditFinancialCategoryUri]
        end

        def payment_default_credit_financial_category_uri=(val)
          attributes[:paymentDefaultCreditFinancialCategoryUri] = val
        end

        def payment_default_debit_financial_category_uri
          attributes[:paymentDefaultDebitFinancialCategoryUri]
        end

        def payment_default_debit_financial_category_uri=(val)
          attributes[:paymentDefaultDebitFinancialCategoryUri] = val
        end

        def fast_payment_default_credit_financial_category_uri
          attributes[:fastPaymentDefaultCreditFinancialCategoryUri]
        end

        def fast_payment_default_credit_financial_category_uri=(val)
          attributes[:fastPaymentDefaultCreditFinancialCategoryUri] = val
        end

        def fast_payment_default_debit_financial_category_uri
          attributes[:fastPaymentDefaultDebitFinancialCategoryUri]
        end

        def fast_payment_default_debit_financial_category_uri=(val)
          attributes[:fastPaymentDefaultDebitFinancialCategoryUri] = val
        end
        
        def transfer_default_credit_financial_category_uri
          attributes[:transferDefaultCreditFinancialCategoryUri]
        end

        def transfer_default_credit_financial_category_uri=(val)
          attributes[:transferDefaultCreditFinancialCategoryUri] = val
        end

        def transfer_default_debit_financial_category_uri
          attributes[:transferDefaultDebitFinancialCategoryUri]
        end

        def transfer_default_debit_financial_category_uri=(val)
          attributes[:transferDefaultDebitFinancialCategoryUri] = val
        end

        def expost_payment_default_credit_financial_category_uri
          attributes[:expostPaymentDefaultCreditFinancialCategoryUri]
        end

        def expost_payment_default_credit_financial_category_uri=(val)
          attributes[:expostPaymentDefaultCreditFinancialCategoryUri] = val
        end

        def expost_payment_default_debit_financial_category_uri
          attributes[:expostPaymentDefaultDebitFinancialCategoryUri]
        end

        def expost_payment_default_debit_financial_category_uri=(val)
          attributes[:expostPaymentDefaultDebitFinancialCategoryUri] = val
        end

        def credit_note_supplier_default_financial_category_uri
          attributes[:creditNoteSupplierDefaultFinancialCategoryUri]
        end

        def credit_note_supplier_default_financial_category_uri=(val)
          attributes[:creditNoteSupplierDefaultFinancialCategoryUri] = val
        end

        def credit_note_client_default_financial_category_uri
          attributes[:creditNoteClientDefaultFinancialCategoryUri]
        end

        def credit_note_client_default_financial_category_uri=(val)
          attributes[:creditNoteClientDefaultFinancialCategoryUri] = val
        end

        def business_case_type
          attributes[:businessCaseType]
        end

        def business_case_type=(val)
          attributes[:businessCaseType] = val
        end

        def dry_run
          attributes[:dryRun]
        end

        def dry_run=(val)
          attributes[:dryRun] = val
        end

      end
    end
  end
end
