require 'uu/os/qos/qos_handler'
require 'uu/os/rest'
require 'uu/os/uesuri'
require 'uu/finman/contract/contract_attributes'
require 'uu/finman/contract/contract_set_attributes'

# Module Unicorn Universe.
module UU
  # Module Finman.
  module Finman
    # Module of Contract
    module Contract
      extend self

      # Service path
      PATH = 'uu/finman/contract/Contract'

      # Obtains Contract attributes from REST service and returns them
      #
      # @param [String,UU::OS::UESURI] contract_uri UESURI of Contract.
      #
      # @return [UU::Finman::Contract::ContractAttributes] Contract attributes
      #
      #
      # @example
      #      # Prepare Contract URI, where we want to get attributes.
      #      contract_uri = UU::OS::UESURI.new('ues:TERRITORY:ARTIFACT');
      #
      #      # Get Contract attributes
      #      UU::Finman::Contract.get_attributes(contract_uri);
      def get_attributes(contract_uri)
        svc = UU::OS::REST::RemoteClient.new(Contract)
        UU::OS::QoS::QoSHandler.auto_retry do
          attrs_string = svc.get('getAttributes', contract_uri)
          attrs = JSON.parse(attrs_string, :symbolize_names => true)
          return UU::Finman::Contract::ContractAttributes.new(attrs)
        end
      end

      # Sets attributes of Contract.
      #
      # @param [String,UU::OS::UESURI] contract_uri UESURI of modified Contract.
      # @param [UU::Finman::Contract::ContractSetAttributes] contract_set_attributes DTO containing modified attributes of the Contract.
      #
      # @return [UU::OS::UESURI] UESURI of modified Contract
      #
      #
      # @example
      #      # Prepare Contract URI, where we want to set attributes.
      #      contract_uri = UU::OS::UESURI.new('ues:TERRITORY:ARTIFACT');
      #
      #      # Set Contract attributes.
      #      UU::Finman::Contract.set_attributes(contract_uri,
      #        :name => "Name");

      #      # Unset Contract attributes.
      #      UU::Finman::Contract.set_attributes(contract_uri,
      #        :name => "",
      #        :credit_account_uri => UU::OS::UESURI.new('ues:[-1]:[-1]'),
      #        :amount_without_vat => "",
      #        :control_side => "");
      def set_attributes(contract_uri, contract_set_attributes)
        svc = UU::OS::REST::RemoteClient.new(Contract)
        a_attrs = UU::Finman::Contract::ContractSetAttributes.new(contract_set_attributes)
        transaction = transform_contract_to_dto(a_attrs).to_json

        UU::OS::QoS::QoSHandler.auto_retry do
          res = svc.post('setAttributes', contract_uri, transaction)
          return UU::OS::UESURI.new(res)
        end
      end

      # Adjust dto of contract to match requirements of contract dto of server side.
      # @private
      def transform_contract_to_dto(acc_dto)
        if acc_dto.is_a?(UU::OS::REST::DTO)
          attributes = acc_dto.to_hash
          return attributes
        end
        fail "Given object is neither UU::OS::REST::DTO nor its descendant!"
      end
      private :transform_contract_to_dto



    end
  end
end
